@@ -2,9 +2,9 @@
 use 5.008001; use utf8; use strict; use warnings;
 
 package Rosetta::Validator;
-our $VERSION = '0.44';
+our $VERSION = '0.45';
 
-use Rosetta 0.44;
+use Rosetta 0.45;
 
 ######################################################################
 
@@ -22,22 +22,23 @@ Core Modules: I<none>
 
 Non-Core Modules: 
 
-	Rosetta 0.44
+	Rosetta 0.45
 
 =head1 COPYRIGHT AND LICENSE
 
 This file is part of the Rosetta database portability library.
 
-Rosetta is Copyright (c) 1999-2005, Darren R. Duncan.  All rights reserved.
-Address comments, suggestions, and bug reports to B<perl@DarrenDuncan.net>, or
-visit "http://www.DarrenDuncan.net" for more information.
+Rosetta is Copyright (c) 2002-2005, Darren R. Duncan.  All rights reserved.
+Address comments, suggestions, and bug reports to perl@DarrenDuncan.net, or
+visit http://www.DarrenDuncan.net/ for more information.
 
 Rosetta is free software; you can redistribute it and/or modify it under the
-terms of the GNU General Public License (GPL) version 2 as published by the
-Free Software Foundation (http://www.fsf.org/).  You should have received a
-copy of the GPL as part of the Rosetta distribution, in the file named
-"LICENSE"; if not, write to the Free Software Foundation, Inc., 59 Temple
-Place, Suite 330, Boston, MA 02111-1307 USA.
+terms of the GNU General Public License (GPL) as published by the Free Software
+Foundation (http://www.fsf.org/); either version 2 of the License, or (at your
+option) any later version.  You should have received a copy of the GPL as part
+of the Rosetta distribution, in the file named "GPL"; if not, write to the
+Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+02111-1307 USA.
 
 Linking Rosetta statically or dynamically with other modules is making a
 combined work based on Rosetta.  Thus, the terms and conditions of the GPL
